@@ -156,7 +156,7 @@ class SummaryPlotter:
                 label_kwargs={"fontsize": 18},
                 # range=ranges, todo: Reimplement
                 quantiles=[0.16, 0.84],
-                levels=iter([1 - np.exp(-0.5) for _ in self.mcmc_params]),
+                levels=tuple([1 - np.exp(-0.5) for _ in self.mcmc_params]),
                 truths=np.zeros(len(self.config.tex_labels)),
                 show_titles=True,
                 title_kwargs={"fontsize": 18},
@@ -169,9 +169,6 @@ class SummaryPlotter:
                 labels=self.config.tex_labels,
                 label_kwargs={"fontsize": 18},
                 quantiles=[0.16, 0.84],
-                # levels=iter(
-                # [1 - np.exp(-0.5) for _ in self.mcmc_params]
-                # ),
                 truths=np.zeros(len(self.config.tex_labels)),
                 show_titles=True,
                 title_kwargs={"fontsize": 18},
